@@ -5,8 +5,7 @@ use strict;
 use warnings;
 use HTTP::Server::Simple;
 
-use vars qw($VERSION %ENV_MAPPING);
-$VERSION = $HTTP::Server::Simple::VERSION;
+use vars qw(%ENV_MAPPING);
 
 my %clean_env = %ENV;
 
@@ -32,7 +31,7 @@ start-up state.
 sub setup_environment {
     %ENV = (
         %clean_env,
-        SERVER_SOFTWARE   => "HTTP::Server::Simple/$VERSION",
+        SERVER_SOFTWARE   => "HTTP::Server::Simple/$HTTP::Server::Simple::VERSION",
         GATEWAY_INTERFACE => 'CGI/1.1'
     );
 }
@@ -66,6 +65,7 @@ See the docs in L<HTTP::Server::Simple> for more detail.
     method       => "REQUEST_METHOD",
     peeraddr     => "REMOTE_ADDR",
     peername     => "REMOTE_HOST",
+    peerport     => "REMOTE_PORT",
     query_string => "QUERY_STRING",
 );
 
